@@ -12,7 +12,7 @@ events or behaviors for each test.
 
 """
 
-import subprocess
+import subprocess32 as subprocess
 import os
 import sys
 import re
@@ -115,7 +115,10 @@ def node_shutdown(g):
     global compute_nodes
     if g.group(1) in compute_nodes:
         del compute_nodes[g.group(1)]
-    return 0
+        return 0
+    else:
+        return 1
+
 
 def jobs_req(g):
     global all_jobs
